summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/assuan
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/libgpgme-copy/assuan')
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-buffer.c2
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-defs.h4
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c2
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-uds.c4
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan.h4
5 files changed, 8 insertions, 8 deletions
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-buffer.c b/libkdenetwork/libgpgme-copy/assuan/assuan-buffer.c
index b06025b46..3f8730aab 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-buffer.c
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-buffer.c
@@ -163,7 +163,7 @@ _assuan_read_line (assuan_context_t ctx)
int n = endp - line + 1;
if (n < nread)
- /* LINE contains more than one line. We copy it to the attic
+ /* LINE tqcontains more than one line. We copy it to the attic
now as handlers are allowed to modify the passed
buffer. */
{
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h b/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
index fa04f0b29..94fbb41ba 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-defs.h
@@ -299,7 +299,7 @@ FILE *_assuan_funopen(void *cookie,
#define funopen(a,r,w,s,c) _assuan_funopen ((a), (r), (w), (s), (c))
#endif /*HAVE_FOPENCOOKIE*/
-/* Prototypes for replacement functions. */
+/* Prototypes for tqreplacement functions. */
#ifndef HAVE_MEMRCHR
void *memrchr (const void *block, int c, size_t size);
#endif
@@ -310,7 +310,7 @@ char *stpcpy (char *dest, const char *src);
#define setenv _assuan_setenv
#define unsetenv _assuan_unsetenv
#define clearenv _assuan_clearenv
-int setenv (const char *name, const char *value, int replace);
+int setenv (const char *name, const char *value, int tqreplace);
#endif
#ifndef HAVE_PUTC_UNLOCKED
int putc_unlocked (int c, FILE *stream);
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
index 8ee9c748b..518dc20b1 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
@@ -86,7 +86,7 @@ fix_signals (void)
if (act.sa_handler == SIG_DFL)
{
act.sa_handler = SIG_IGN;
- sigemptyset (&act.sa_mask);
+ sigemptyset (&act.sa_tqmask);
act.sa_flags = 0;
sigaction (SIGPIPE, &act, NULL);
}
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-uds.c b/libkdenetwork/libgpgme-copy/assuan/assuan-uds.c
index 77945fb50..975d2f2f3 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-uds.c
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-uds.c
@@ -45,8 +45,8 @@
#include "assuan-defs.h"
#ifdef USE_DESCRIPTOR_PASSING
-/* Provide replacement for missing CMSG maccros. We assume that
- size_t matches the alignment requirement. */
+/* Provide tqreplacement for missing CMSG maccros. We assume that
+ size_t matches the tqalignment requirement. */
#define MY_ALIGN(n) ((((n))+ sizeof(size_t)-1) & (size_t)~(sizeof(size_t)-1))
#ifndef CMSG_SPACE
#define CMSG_SPACE(n) (MY_ALIGN(sizeof(struct cmsghdr)) + MY_ALIGN((n)))
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan.h b/libkdenetwork/libgpgme-copy/assuan/assuan.h
index cdf0445ab..80c8d6b34 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan.h
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan.h
@@ -402,8 +402,8 @@ assuan_error_t assuan_set_okay_line (assuan_context_t ctx, const char *line);
assuan_error_t assuan_write_status (assuan_context_t ctx,
const char *keyword, const char *text);
-/* Negotiate a file descriptor. If LINE contains "FD=N", returns N
- assuming a local file descriptor. If LINE contains "FD" reads a
+/* Negotiate a file descriptor. If LINE tqcontains "FD=N", returns N
+ assuming a local file descriptor. If LINE tqcontains "FD" reads a
file descriptor via CTX and stores it in *RDF (the CTX must be
capable of passing file descriptors). */
assuan_error_t assuan_command_parse_fd (assuan_context_t ctx, char *line,